Utf8StringOwned

Type Alias Utf8StringOwned 

pub type Utf8StringOwned = String;
Owned UTF8String value used by formats, such as constructed BER strings, whose contents cannot borrow one contiguous range of the input.

Aliased Type

pub struct Utf8StringOwned { /* private fields */ }